import { Card, Form } from "antd"
import React from "react"
import InputName from "@/components/InputName";
import { txtLength } from "@/utils/utils";
import New1Radio from "@/pages/launchSystemV3/components/New1Radio";
import { AD_STATUS_ENUM } from "../../const";


/**
 * 创意设置
 * @returns 
 */
const CreativeTemplateSetup: React.FC = () => {

    return <Card
        title={< strong style={{ fontSize: 18 }}>创意设置</strong >}
        className="cardResetCss"
    >
        <Form.Item label={<strong>创意状态</strong>} name="configuredStatus" rules={[{ required: true, message: '请选择创意状态' }]}>
            <New1Radio data={Object.keys(AD_STATUS_ENUM).map(key => ({ label: AD_STATUS_ENUM[key], value: key }))} />
        </Form.Item>
        <Form.Item
            label={<strong>创意名称</strong>}
            name='dynamicCreativeName'
            rules={[
                { required: true, message: '请输入创意名称!' },
                {
                    required: true, message: '创意名称不能包含特殊字符：< > & ‘ ” / 以及TAB、换行、回车键，请修改', validator(_, value) {
                        let reg = /[&‘’“”/\n\t\f]/ig
                        if (value && reg.test(value)) {
                            return Promise.reject()
                        }
                        return Promise.resolve()
                    }
                },
                {
                    required: true, message: '请确保创意名称长度不超过60个字（1个汉字等于2个字符)', validator(_, value) {
                        if (value && txtLength(value) > 60) {
                            return Promise.reject()
                        }
                        return Promise.resolve()
                    }
                }
            ]}
        >
            <InputName placeholder='请输入创意名称' style={{ width: 480 }} length={60} />
        </Form.Item>
    </Card>
}

export default React.memo(CreativeTemplateSetup)