import React, { useContext, useEffect, useState } from "react"
import style from '../index.less'
import { Button, Space } from "antd"
import { EditOutlined } from "@ant-design/icons"
import { DispatchAddelivery } from ".."
import NewDynamic from "./newDynamic"
import { AD_STATUS_ENUM, CONVERSION_DATA_ENUM, CONVERSION_TARGET_ENUM, DELIVERY_MODE_ENUM, PAGE_TYPE_ENUM, TEXT_LINK_TYPE_ENUM, pageSpecFieldConVertUn } from "../../const"
import { getCreativeDetailsApi } from "@/services/adqV3/global"
import { useAjax } from "@/Hook/useAjax"
import { processData } from "@/utils/utils"

/**
 * 创意
 * @returns 
 */
const Dynamic: React.FC = () => {

    /***************************************/
    const { addelivery, setAddelivery, setMaterialData, setTextData, clearData } = useContext(DispatchAddelivery)!;
    const { adgroups, dynamic: dynamicData } = addelivery;
    const { marketingGoal, marketingAssetOuterSpec, marketingCarrierType, siteSet, wechatPosition } = adgroups
    const { deliveryMode, creativeTemplateId, dynamicCreativeName, creativeComponents, configuredStatus } = dynamicData
    const { textLink, actionButton, showData, brand } = creativeComponents || {}
    let pageSpec = brand?.[0]?.value?.jumpInfo?.pageSpec
    const [newVisible, setNewVisible] = useState<boolean>(false);
    const [creativeTemplateAppellation, setCreativeTemplateAppellation] = useState<string>()
    const [creativeTemplateStyle, setCreativeTemplateStyle] = useState<string>()

    const getCreativeDetails = useAjax((params) => getCreativeDetailsApi(params))
    /***************************************/

    useEffect(() => {
        if (creativeTemplateId) {
            getCreativeDetails.run({
                marketingGoal,
                marketingTargetType: marketingAssetOuterSpec.marketingTargetType,
                marketingCarrierType,
                siteSet,
                deliveryMode,
                creativeTemplateId,
                wechatSceneSpecPosition: wechatPosition,
                dynamicCreativeType: deliveryMode === 'DELIVERY_MODE_COMPONENT' ? 'DYNAMIC_CREATIVE_TYPE_PROGRAM' : 'DYNAMIC_CREATIVE_TYPE_COMMON'
            }).then(res => {
                if (res?.adcreativeTemplateStructAdpermits?.length > 0) {
                    let adcreativeTemplateStructAdpermits = res?.adcreativeTemplateStructAdpermits[0]
                    setCreativeTemplateAppellation(adcreativeTemplateStructAdpermits.creativeTemplateAppellation)
                    setCreativeTemplateStyle(adcreativeTemplateStructAdpermits.creativeTemplateStyle)

                    let creativeComponents = adcreativeTemplateStructAdpermits?.creativeComponents || []
                    let result = processData(creativeComponents);
            
                    let newMaterialData = {};
                    let newTextData = {};
            
                    Object.keys(result).forEach(key => {
                        let data = result[key]
                        if ((key === 'image_list' || key === 'short_video' || key === 'video' || key === 'image' || key === 'element_story') && data.required) {
                            newMaterialData[key] = data
                        } else if (key === 'title' || (data.required && key === 'description')) {
                            newTextData[key] = data
                        }
                    })
            
                    setMaterialData(newMaterialData)
                    setTextData(newTextData)
                }
            })
        }
    }, [creativeTemplateId, deliveryMode, marketingGoal, marketingAssetOuterSpec, marketingCarrierType, siteSet, wechatPosition])

    return <div className={`${style.settingsBody_content_row} ${style.row3}`}>
        <div className={style.title}>
            <span>创意信息</span>
        </div>
        <div className={style.detail}>
            <div className={style.detail_body}>
                {dynamicData && Object.keys(dynamicData).length > 0 && <>
                    <p>创意名称：{dynamicCreativeName}</p>
                    <p style={{ fontWeight: 'bold', color: '#000' }}>创意状态：{AD_STATUS_ENUM[configuredStatus]}</p>
                    <p>投放模式：{DELIVERY_MODE_ENUM[deliveryMode]}</p>
                    <p>创意形式：{creativeTemplateAppellation || creativeTemplateId}</p>
                    {brand?.length > 0 && <>
                        <p style={{ fontWeight: 'bold', color: '#000' }}>品牌形象跳转：{PAGE_TYPE_ENUM[brand?.[0]?.value?.jumpInfo?.pageType]}</p>
                        {['PAGE_TYPE_H5_PROFILE', 'PAGE_TYPE_NOT_USED'].includes(brand?.[0]?.value?.jumpInfo?.pageType) && <Space align="center">
                            <img src={brand?.[0]?.value?.brandImageId} alt="" width={20} style={{ display: 'block' }} />
                            <span style={{ fontWeight: 'bold', color: '#000', fontSize: 12 }}>{brand?.[0]?.value?.brandName}</span>
                        </Space>}
                        {(pageSpec && Object.keys(pageSpec).length > 0) && <p style={{ fontWeight: 'bold', color: '#000' }}>跳转类型：{PAGE_TYPE_ENUM[pageSpecFieldConVertUn[Object.keys(pageSpec)?.[0]]]}</p>}
                    </>}
                    {textLink?.length > 0 && <>
                        <p style={{ fontWeight: 'bold', color: '#000' }}>朋友圈文字链：开启</p>
                        <p>文字链文案：{TEXT_LINK_TYPE_ENUM[textLink?.[0]?.value?.linkNameType]}</p>
                        {textLink?.[0]?.value?.jumpInfo?.pageType && <p>跳转落地页：{PAGE_TYPE_ENUM[textLink?.[0]?.value?.jumpInfo?.pageType]}</p>}
                    </>}
                    {actionButton?.length > 0 && <>
                        <p style={{ fontWeight: 'bold', color: '#000' }}>行动按钮：开启</p>
                        <p>按钮文案：{actionButton?.[0]?.value?.buttonText}</p>
                        {actionButton?.[0]?.value?.jumpInfo?.pageType && <p>跳转落地页：{PAGE_TYPE_ENUM[actionButton?.[0]?.value?.jumpInfo?.pageType]}</p>}
                    </>}
                    {showData?.length > 0 && <>
                        <p style={{ fontWeight: 'bold', color: '#000' }}>数据外显：开启</p>
                        <p>数据类型：{CONVERSION_DATA_ENUM[showData?.[0]?.value?.conversionDataType]}</p>
                        <p>转化行为：{CONVERSION_TARGET_ENUM[showData?.[0]?.value?.conversionTargetType]}</p>
                    </>}
                </>}
            </div>
            <div className={style.detail_footer}>
                <Button disabled={!(adgroups && Object.keys(adgroups)?.length > 0)} type="link" icon={<EditOutlined />} style={{ padding: 0, fontSize: 12 }} onClick={() => setNewVisible(true)}>编辑</Button>
            </div>
        </div>

        {newVisible && <NewDynamic
            visible={newVisible}
            creativeTemplateStyle={creativeTemplateStyle}
            value={dynamicData}
            onClose={() => {
                setNewVisible(false)
            }}
            onChange={(dynamic) => {
                setAddelivery({ ...addelivery, dynamic, dynamicMaterialDTos: {}, dynamicCreativesTextDTOS: {} })
                setNewVisible(false)
                clearData()
            }}
        />}
    </div>
}

export default React.memo(Dynamic)