import { useAjax } from "@/Hook/useAjax"
import { getTaskV3LogListApi } from "@/services/adqV3"
import { Drawer, Table } from "antd"
import React, { useEffect, useState } from "react"
import { columnsLog } from "./tableConfig"

interface Props {
    data: any
    visible?: boolean,
    onClose?: () => void
}
/**
 * 创建日志
 * @returns 
 */
const Log: React.FC<Props> = (props) => {

    /*****************************/
    const { data, visible, onClose } = props
    console.log(data)
    const { id, taskName } = data
    const [queryForm, setQueryForm] = useState<PULLIN.GetTaskV3LogProps>({ pageNum: 1, pageSize: 20 })

    const getTaskV3LogList = useAjax((params) => getTaskV3LogListApi(params), { formatResult: true })
    /*****************************/

    useEffect(() => {
        getList()
    }, [queryForm, id])

    /** 获取列表 */
    const getList = () => {
        if (id) {
            getTaskV3LogList.run({ ...queryForm, taskId: id })
        }
    }

    return <Drawer bodyStyle={{ padding: 0 }} title={taskName + ' 日志'} width={1400} placement="right" onClose={() => { onClose && onClose() }} visible={visible}>
        <Table
            columns={columnsLog()}
            dataSource={getTaskV3LogList?.data?.data?.records}
            size="small"
            loading={getTaskV3LogList?.loading}
            scroll={{ y: 500 }}
            bordered
            rowKey={'id'}
            pagination={{
                pageSize: queryForm.pageSize,
                current: queryForm.pageNum,
                total: getTaskV3LogList?.data?.data?.total || 0
            }}
            onChange={(pagination) => {
                let { current, pageSize } = pagination
                let newQueryForm = JSON.parse(JSON.stringify(queryForm))
                newQueryForm.pageNum = current
                newQueryForm.pageSize = pageSize
                setQueryForm(newQueryForm)
            }}
        />
    </Drawer>
}


export default React.memo(Log)