import React from "react"
import { Badge, Popover, Space, TableProps, Typography } from "antd"
import { AD_STATUS_ENUM, MARKETING_GOAL_ENUM } from "../const"
import TargetingTooltip from "../../components/TargetingTooltip"
import { QuestionCircleFilled } from "@ant-design/icons"
import AdgroupTooltip from "../../components/AdgroupTooltip"
import DynamicTooltip from "../../components/DynamicTooltip"


const columns = (geoLocationList: any, modelList: any, callback: (data: any, type: 'log' | 'page' | 'copy', allData?: any) => void): TableProps<any>['columns'] => {

    return [
        {
            title: '操作',
            dataIndex: 'cz',
            key: 'cz',
            width: 80,
            align: 'center',
            render: (_, records) => {
                return <Space>
                    <a style={{ color: '#1890ff', fontSize: 12 }} onClick={() => { callback(records, 'log', records) }}>日志</a>
                    {/* <a style={{ color: '#1890ff', fontSize: 12 }} onClick={() => { callback({ taskId: b.id, campaignName: b.campaignName,putModel:b.putModel }, 'copy') }}>复制</a> */}
                </Space>
            }
        },
        {
            title: '任务名称',
            dataIndex: 'taskName',
            key: 'taskName',
            align: 'center',
            width: 120,
            ellipsis: true
        },
        {
            title: 'ID',
            dataIndex: 'id',
            key: 'id',
            align: 'center',
            width: 50,
        },
        {
            title: '广告状态',
            dataIndex: 'configuredStatus',
            key: 'configuredStatus',
            align: 'center',
            width: 80,
            render: (_, b) => {
                let configuredStatus = b?.adgroupDTO?.configuredStatus
                if (configuredStatus) {
                    return <span style={{ fontSize: "12px" }}>{AD_STATUS_ENUM[configuredStatus]}</span>
                } else {
                    return <span>--</span>
                }
            }
        },
        {
            title: '广告详情',
            dataIndex: 'adgroupDTO',
            key: 'adgroupDTO',
            width: 200,
            ellipsis: true,
            render(value) {
                return <div style={{ width: '100%', display: 'flex', alignItems: 'center' }}>
                    <div style={{ width: 'calc(100% - 20px)' }}><Typography.Text ellipsis={{ tooltip: true }}>{value?.adgroupName}</Typography.Text></div>
                    <Popover
                        placement="right"
                        overlayInnerStyle={{ maxWidth: 350, maxHeight: 350, overflow: 'hidden', overflowY: 'auto' }}
                        mouseEnterDelay={0.5}
                        content={<AdgroupTooltip
                            data={value}
                        />}
                    >
                        <QuestionCircleFilled />
                    </Popover>
                </div>
            }
        },
        {
            title: '定向详情',
            dataIndex: 'targetings',
            key: 'targetings',
            width: 300,
            render(value) {
                return <div style={{ width: '100%', display: 'flex', alignItems: 'center', gap: 10, overflow: 'hidden', overflowX: 'auto' }}>
                    {value?.map((item: any, index: number) => <Popover
                        key={index}
                        placement="right"
                        overlayInnerStyle={{ maxWidth: 350, maxHeight: 350, overflow: 'hidden', overflowY: 'auto' }}
                        mouseEnterDelay={1}
                        content={<TargetingTooltip
                            data={item}
                            geoLocationList={geoLocationList}
                            modelList={modelList}
                        />}
                    >
                        <div style={{ width: 80, cursor: 'help' }}><Typography.Text ellipsis>{index + 1}、{item?.targetingName || '--'}</Typography.Text></div>
                    </Popover>)}
                </div>
            }
        },
        {
            title: '创意详情',
            dataIndex: 'dynamicCreativesDTO',
            key: 'dynamicCreativesDTO',
            width: 200,
            ellipsis: true,
            render(value) {
                return <div style={{ width: '100%', display: 'flex', alignItems: 'center' }}>
                    <div style={{ width: 'calc(100% - 20px)' }}><Typography.Text ellipsis={{ tooltip: true }}>{value?.dynamicCreativeName}</Typography.Text></div>
                    <Popover
                        placement="right"
                        overlayInnerStyle={{ maxWidth: 350, maxHeight: 350, overflow: 'hidden', overflowY: 'auto' }}
                        mouseEnterDelay={0.5}
                        content={<DynamicTooltip
                            data={value}
                        />}
                    >
                        <QuestionCircleFilled />
                    </Popover>
                </div>
            }
        },
        {
            title: '创建时间',
            dataIndex: 'createTime',
            key: 'createTime',
            align: 'center',
            width: 140,
            render: (value) => {
                return <span style={{ fontSize: "12px" }}>{value || '--'}</span>
            }
        },
        {
            title: <span style={{ marginLeft: 10 }}>任务反馈</span>,
            dataIndex: 'total',
            key: 'total',
            render: (value, records) => {
                return <Space style={{ fontSize: "12px", marginLeft: 10 }} size={20}>
                    <span><Badge status="processing" />总条数：{value}条</span>
                    {<span><Badge status="success" />成功数：{records?.successCount || 0}条</span>}
                    {/* {errCount ? <span><Badge status="error" />创建中：{errCount}条</span> : null} */}
                </Space>
            }
        }
    ]
}

export const columnsLog = (): TableProps<any>['columns'] => {
    return [
        {
            title: '广告账号',
            dataIndex: 'accountId',
            key: 'accountId',
            width: 100,
            ellipsis: true,
            align: 'center'
        },
        {
            title: '广告名称',
            dataIndex: 'adgroupName',
            key: 'adgroupName',
            width: 160,
            ellipsis: true
        },
        {
            title: '定向名称',
            dataIndex: 'targetingsName',
            key: 'targetingsName',
            width: 150,
            ellipsis: true
        },
        {
            title: '营销目的',
            dataIndex: 'marketingGoal',
            key: 'marketingGoal',
            width: 100,
            ellipsis: true,
            align: 'center',
            render(value) {
                return MARKETING_GOAL_ENUM[value]
            },
        },
        {
            title: '出价',
            dataIndex: 'bidAmount',
            key: 'bidAmount',
            width: 90,
            align: 'center'
        },
        {
            title: '错误信息',
            dataIndex: 'failMsg',
            key: 'failMsg',
            width: 180,
            ellipsis: true
        },
    ]
}

export default columns